@@ -221,10 +221,10 @@ class FileMonitor(object):
         '''Backup a remote file or folder to local. Add an entry into rollback.json.'''
         if sys_conf == None:
             return;
-        nodes = sys_conf['cluster_service_nodes']
+        nodesIp = sys_conf['cluster_service_nodes']
         if not nodes:
             return
-        print('backup remote file [%s] of [%s]' % (REMOTE_ALERT_CNF_FILE, nodes[0]['ip']))
+        print('backup remote file [%s] of [%s]' % (REMOTE_ALERT_CNF_FILE, nodesIp[0]))
         
         # create necessary folders
         d = os.path.dirname(LOCAL_ALERT_CNF_FILE)
@@ -238,12 +238,12 @@ class FileMonitor(object):
         # only backup one of the remote nodes for now.
         client = None
         try:
-            client = SSHCommander(nodes[0]['ip'], nodes[0]['user'], nodes[0]['password'])
-            cmdstr = 'su root -c "\cp %s %s"' % (REMOTE_ALERT_CNF_FILE, shared_file)
-            status, output = client.execute_interactive(cmdstr, nodes[0]['rootPasswd'])
+            client = SSHCommander(nodesIp[0])
+            cmdstr = 'sudo sh -c "\cp %s %s"' % (REMOTE_ALERT_CNF_FILE, shared_file)
+            status, output = client.execute_interactive(cmdstr)
             print(output)
             if status != 0:
-                raise Exception("failed to backup remote file on " + nodes[0]['ip'])
+                raise Exception("failed to backup remote file on " + nodesIp[0])
             
             # use 'move' to reduce waste temporary files
             shutil.move(shared_file, LOCAL_ALERT_CNF_FILE)
@@ -434,13 +434,13 @@ class DataMonitor(object):
         return DataMonitor.ID_DELIMETER.join(values)
     
 def getCMSWathpointVersion():    
-    versionString = os.popen("rpm -qi watchpoint-cms  | grep Version | awk '{print $3}'", "r").read().strip() 
+    versionString = os.popen("sudo rpm -qi watchpoint-cms  | sudo grep Version | sudo awk '{print $3}'", "r").read().strip() 
     if versionString is not None and len(versionString) > 0:
             # After 3.1, RPM is used instead of conary to manage CMS package
         return versionString
     else:
         # If reach this point, it means the cms version is before 3.1
-        versionString = os.popen("conary q | grep watchpoint-cms | awk '{print $1}' | cut -d '=' -f2", "r").read().strip()
+        versionString = os.popen("conary q | sudo grep watchpoint-cms | sudo awk '{print $1}' | cut -d '=' -f2", "r").read().strip()
         return versionString
 
 def initSysConfig(sys_info_file):
